summaryrefslogtreecommitdiff
path: root/src/network/core/tcp_http.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/network/core/tcp_http.h')
-rw-r--r--src/network/core/tcp_http.h16
1 files changed, 7 insertions, 9 deletions
diff --git a/src/network/core/tcp_http.h b/src/network/core/tcp_http.h
index 1a1edaf87..cc9a3adac 100644
--- a/src/network/core/tcp_http.h
+++ b/src/network/core/tcp_http.h
@@ -81,16 +81,14 @@ class NetworkHTTPContentConnecter : TCPConnecter {
public:
/**
* Start the connecting.
* @param address the address to connect to
* @param callback the callback for HTTP retrieval
* @param url the url at the server
* @param data the data to send
* @param depth the depth (redirect recursion) of the queries
*/
- NetworkHTTPContentConnecter(const NetworkAddress &address,
- HTTPCallback *callback, const char *url,
- const char *data = nullptr, int depth = 0) :
- TCPConnecter(address),
+ NetworkHTTPContentConnecter(const std::string &connection_string, HTTPCallback *callback, const char *url, const char *data = nullptr, int depth = 0) :
+ TCPConnecter(connection_string, 80),
callback(callback),
url(stredup(url)),
data(data),
@@ -81,16 +81,14 @@ class NetworkHTTPContentConnecter : TCPConnecter {
/**
* Start the connecting.
- * @param address the address to connect to
- * @param callback the callback for HTTP retrieval
- * @param url the url at the server
- * @param data the data to send
- * @param depth the depth (redirect recursion) of the queries
+ * @param connection_string The address to connect to.
+ * @param callback The callback for HTTP retrieval.
+ * @param url The url at the server.
+ * @param data The data to send.
+ * @param depth The depth (redirect recursion) of the queries.
*/